@@ -44,7 +44,6 @@
 #include <QSizePolicy>
 #include <QStatusBar>
 #include <QStringList>
-#include <QTextStream>
 #include <QtGlobal>
 
 #include <KComboBox>
@@ -1130,7 +1129,6 @@ void Kwave::TopWidget::metaDataChanged(Kwave::MetaDataList meta_data)
 {
     Q_ASSERT(statusBar());
     if (!statusBar() || !m_menu_manager) return;
-    double ms;
     QString txt;
 
     const Kwave::FileInfo info(meta_data);
@@ -1141,7 +1139,7 @@ void Kwave::TopWidget::metaDataChanged(Kwave::MetaDataList meta_data)
 
     // length in milliseconds
     if (length) {
-	ms = (rate > 0) ? (static_cast<double>(length) /
+	double ms = (rate > 0) ? (static_cast<double>(length) /
 	    static_cast<double>(rate) * 1E3) : 0;
 	txt = _(" ") + i18nc(
 	    "Length, as in total duration of loaded song",
@@ -1294,21 +1292,6 @@ void Kwave::TopWidget::setUndoRedoInfo(const QString &undo,
     m_menu_manager->setItemText(_("ID_EDIT_REDO"), txt);
 }
 
-//***************************************************************************
-void Kwave::TopWidget::mouseChanged(Kwave::MouseMark::Mode mode,
-                                    sample_index_t offset,
-                                    sample_index_t length)
-{
-    switch (mode) {
-	case (Kwave::MouseMark::MouseAtSelectionBorder) :
-	case (Kwave::MouseMark::MouseInSelection) :
-	    selectionChanged(offset, length);
-	    break;
-	default:
-	    ;
-    }
-}
-
 //***************************************************************************
 void Kwave::TopWidget::clipboardChanged(bool data_available)
 {
@@ -1325,7 +1308,7 @@ void Kwave::TopWidget::updateRecentFiles()
 
     foreach (const QString &file, m_application.recentFiles())
 	m_menu_manager->addNumberedMenuEntry(
-	    _("ID_FILE_OPEN_RECENT"), file);
+	    _("ID_FILE_OPEN_RECENT"), file, QString());
 
     // enable/disable the "clear" menu entry in Files / Open Recent
     m_menu_manager->setItemEnabled(_("ID_FILE_OPEN_RECENT_CLEAR"),
@@ -1385,7 +1368,8 @@ void Kwave::TopWidget::updateMenu()
 	    if (!context) continue;
 	    QString caption = context->windowCaption(false);
 	    if (!caption.length()) continue;
-	    m_menu_manager->addNumberedMenuEntry(_("ID_WINDOW_LIST"), caption);
+	    m_menu_manager->addNumberedMenuEntry(_("ID_WINDOW_LIST"),
+	        caption, QString());
 	    ++win_count;
 	}
 
@@ -1402,10 +1386,37 @@ void Kwave::TopWidget::updateMenu()
     m_menu_manager->setItemEnabled(_("@NOT_CLOSED"), have_file);
 
     // enable/disable all items that depend on having a label
+    // and update the label menu
     bool have_labels = false;
     if (signal_manager) {
 	Kwave::LabelList labels(signal_manager->metaData());
 	have_labels = !labels.isEmpty();
+
+	m_menu_manager->clearNumberedMenu(_("ID_LABEL_DELETE"));
+	if (labels.count()) {
+
+	    // add special entry to delete all labels
+	    m_menu_manager->addNumberedMenuEntry(
+		_("ID_LABEL_DELETE"),
+		i18nc("special entry in the list of labels to delete all",
+		      "(All)"), _("-1"));
+
+	    // iterate over the list of labels
+	    unsigned int index = 0;
+	    foreach (const Kwave::Label &label, labels) {
+		QString name = label.name();
+		QString desc = (name.length()) ?
+		i18nc(
+		    "list menu entry of a label, %1=index, %2=description/name",
+		    "#%1 (%2)", index, name) :
+		    i18nc("list menue entry of a label, "
+			    "without description, %1=index",
+			    "#%1", index);
+		m_menu_manager->addNumberedMenuEntry(
+		    _("ID_LABEL_DELETE"), desc, name.setNum(index));
+		index++;
+	    }
+	}
     }
     m_menu_manager->setItemEnabled(_("@LABELS"), have_labels);
 
@@ -1415,7 +1426,7 @@ void Kwave::TopWidget::updateMenu()
     QString buf;
     for (unsigned int i = 0; i < tracks; i++) {
 	m_menu_manager->addNumberedMenuEntry(
-	    _("ID_EDIT_TRACK_DELETE"), buf.setNum(i));
+	    _("ID_EDIT_TRACK_DELETE"), buf.setNum(i), buf.setNum(i));
     }
 
     // enable/disable all items that depend on having a signal
