@@ -207,7 +207,7 @@ int Kwave::SignalManager::loadFile(const QUrl &url)
 	bool use_src_size = (!resulting_size);
 	if (use_src_size) resulting_size = src.size();
 
-	//prepare and show the progress dialog
+	// prepare and show the progress dialog
 	dialog = new Kwave::FileProgress(m_parent_widget,
 	    QUrl(filename), resulting_size,
 	    info.length(), info.rate(), info.bits(), info.tracks());
@@ -343,30 +343,23 @@ int Kwave::SignalManager::save(const QUrl &url, bool selection)
 	file_info.set(Kwave::INF_MIMETYPE, mimetype_name);
 
 	// check if we lose information and ask the user if this would
-	// be acceptable if so
-	QList<Kwave::FileProperty> supported = encoder->supportedProperties();
-	QMap<Kwave::FileProperty, QVariant> properties(file_info.properties());
-	bool all_supported = true;
-	QMap<Kwave::FileProperty, QVariant>::Iterator it;
-	QString lost_properties;
-	for (it = properties.begin(); it != properties.end(); ++it) {
-	    if ( (! supported.contains(it.key())) &&
-                 (file_info.canLoadSave(it.key())) )
-	    {
-		qWarning("SignalManager::save(): unsupported property '%s'",
-		    DBG(file_info.name(it.key())));
-		all_supported = false;
-		lost_properties += i18n(UTF8(file_info.name(it.key()))) + _("\n");
+	// be acceptable
+	QList<Kwave::FileProperty> unsupported = encoder->unsupportedProperties(
+	    file_info.properties().keys());
+	if (!unsupported.isEmpty()) {
+	    QString list_of_lost_properties = _("\n");
+	    foreach (const Kwave::FileProperty &p, unsupported) {
+		list_of_lost_properties +=
+		    i18n(UTF8(file_info.name(p))) + _("\n");
 	    }
-	}
-	if (!all_supported) {
+
 	    // show a warning to the user and ask him if he wants to continue
 	    if (Kwave::MessageBox::warningContinueCancel(m_parent_widget,
 		i18n("Saving in this format will lose the following "
 		     "additional file attribute(s):\n"
 		     "%1\n"
 		     "Do you still want to continue?",
-		     lost_properties),
+		     list_of_lost_properties),
 		QString(),
 		QString(),
 		QString(),
@@ -399,7 +392,7 @@ int Kwave::SignalManager::save(const QUrl &url, bool selection)
 	    const KAboutData about_data = KAboutData::applicationData();
 	    QString software = about_data.displayName() + _("-") +
 	                       about_data.version() +
-	                       i18n("(built for KDE Frameworks %1)",
+	                       i18n("(built with KDE Frameworks %1)",
 	                            _(KXMLGUI_VERSION_STRING));
 	    file_info.set(Kwave::INF_SOFTWARE, software);
 	}
@@ -563,7 +556,7 @@ void Kwave::SignalManager::close()
     m_selection.clear();
 
     m_empty = true;
-    while (tracks()) deleteTrack(tracks()-1);
+    while (tracks()) deleteTrack(tracks() - 1);
     m_signal.close();
 
     // clear all meta data
@@ -729,7 +722,7 @@ int Kwave::SignalManager::executeCommand(const QString &command)
 //	    }
 //	}
 
-    CASE_COMMAND("delete_label")
+    CASE_COMMAND("label:delete")
 	int index = parser.toInt();
 	deleteLabel(index, true);
 
@@ -1336,7 +1329,9 @@ void Kwave::SignalManager::enableUndo()
 //***************************************************************************
 void Kwave::SignalManager::disableUndo()
 {
-    Q_ASSERT(m_undo_transaction_level == 0);
+    if (m_undo_transaction_level)
+	qWarning("SignalManager::disableUndo(): undo transaction level=%u",
+	    m_undo_transaction_level);
 
     flushUndoBuffers();
     m_undo_enabled = false;
@@ -1837,7 +1832,7 @@ void Kwave::SignalManager::enableModifiedChange(bool en)
 }
 
 //***************************************************************************
-void Kwave::SignalManager::setFileInfo(Kwave::FileInfo &new_info,
+void Kwave::SignalManager::setFileInfo(const Kwave::FileInfo &new_info,
                                        bool with_undo)
 {
     if (m_undo_enabled && with_undo) {
@@ -1912,20 +1907,43 @@ Kwave::Label Kwave::SignalManager::addLabel(sample_index_t pos,
 void Kwave::SignalManager::deleteLabel(int index, bool with_undo)
 {
     Kwave::LabelList labels(m_meta_data);
+    int count = Kwave::toInt(labels.count());
+    if (!count) return;
 
-    if ((index < 0) || (index >= Kwave::toInt(labels.count()))) return;
+    if (index == -1) {
+	// special handling for index == -1 -> delete all labels
 
-    Kwave::MetaData label(labels.at(index));
+	if (with_undo) startUndoTransaction(i18n("Delete All Labels"));
 
-    // register the undo action
-    if (with_undo) {
-	Kwave::UndoTransactionGuard undo(*this, i18n("Delete Label"));
-	if (!registerUndoAction(new(std::nothrow)
-	    UndoDeleteMetaDataAction(Kwave::MetaDataList(label))))
-	    return;
+	for (index = count - 1; index >= 0; index--) {
+	    Kwave::MetaData label(labels.at(index));
+	    if (with_undo) {
+		if (!registerUndoAction(new(std::nothrow)
+		    UndoDeleteMetaDataAction(Kwave::MetaDataList(label))))
+		    break;
+	    }
+	    m_meta_data.remove(label);
+	}
+    } else {
+	// delete a single label
+	if ((index < 0) || (index >= count)) return;
+
+	Kwave::MetaData label(labels.at(index));
+
+	// register the undo action
+	if (with_undo) {
+	    startUndoTransaction(i18n("Delete Label"));
+	    if (!registerUndoAction(new(std::nothrow)
+		UndoDeleteMetaDataAction(Kwave::MetaDataList(label)))) {
+		abortUndoTransaction();
+		return;
+	    }
+	}
+
+	m_meta_data.remove(label);
     }
 
-    m_meta_data.remove(label);
+    if (with_undo) closeUndoTransaction();
 
     // register this as a modification
     setModified(true);
@@ -1935,7 +1953,8 @@ void Kwave::SignalManager::deleteLabel(int index, bool with_undo)
 
 //***************************************************************************
 bool Kwave::SignalManager::modifyLabel(int index, sample_index_t pos,
-                                       const QString &name)
+                                       const QString &name,
+                                       bool with_undo)
 {
     Kwave::LabelList labels(m_meta_data);
     if ((index < 0) || (index >= Kwave::toInt(labels.count())))
@@ -1949,7 +1968,7 @@ bool Kwave::SignalManager::modifyLabel(int index, sample_index_t pos,
 	return false;
 
     // add a undo action
-    if (m_undo_enabled) {
+    if (with_undo && m_undo_enabled) {
 	Kwave::UndoModifyMetaDataAction *undo_modify =
 	    new(std::nothrow) Kwave::UndoModifyMetaDataAction(
 	            Kwave::MetaDataList(label));
@@ -1969,6 +1988,13 @@ bool Kwave::SignalManager::modifyLabel(int index, sample_index_t pos,
     return true;
 }
 
+//***************************************************************************
+void Kwave::SignalManager::mergeMetaData(const Kwave::MetaDataList &meta_data)
+{
+    m_meta_data.merge(meta_data);
+    emit sigMetaDataChanged(m_meta_data);
+}
+
 //***************************************************************************
 void Kwave::SignalManager::rememberCurrentSelection()
 {
